Index: inc/editstat.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/editstat.hxx,v
retrieving revision 1.5
retrieving revision 1.5.106.1
diff -u -r1.5 -r1.5.106.1
--- inc/editstat.hxx	8 Sep 2005 17:32:27 -0000	1.5
+++ inc/editstat.hxx	26 Oct 2005 18:06:50 -0000	1.5.106.1
@@ -101,7 +101,7 @@
 	EE_STAT_CRSRLEFTPARA zur Zeit bei Cursorbewegungen und Return.
 */
 
-inline void SetFlags( ULONG& rBits, const ULONG nMask, FASTBOOL bOn )
+inline void SetFlags( sal_uInt32& rBits, const sal_uInt32 nMask, FASTBOOL bOn )
 {
 	if ( bOn )
 		rBits |= nMask;
@@ -112,22 +112,22 @@
 class EditStatus
 {
 protected:
-	ULONG	nStatusBits;
-	ULONG	nControlBits;
+	sal_uInt32	nStatusBits;
+	sal_uInt32	nControlBits;
 	USHORT	nPrevPara;					// fuer EE_STAT_CRSRLEFTPARA
 
 public:
 			EditStatus()				{ nStatusBits = 0; nControlBits = 0; nPrevPara = 0xFFFF; }
 
 	void	Clear() 					{ nStatusBits = 0; }
-	void	SetControlBits( ULONG nMask, FASTBOOL bOn )
+	void	SetControlBits( sal_uInt32 nMask, FASTBOOL bOn )
 				{ SetFlags( nControlBits, nMask, bOn ); }
 
-	ULONG	GetStatusWord() const		{ return nStatusBits; }
-	ULONG&	GetStatusWord() 			{ return nStatusBits; }
+	sal_uInt32	GetStatusWord() const		{ return nStatusBits; }
+	sal_uInt32&	GetStatusWord() 			{ return nStatusBits; }
 
-	ULONG	GetControlWord() const		{ return nControlBits; }
-	ULONG&	GetControlWord() 			{ return nControlBits; }
+	sal_uInt32	GetControlWord() const		{ return nControlBits; }
+	sal_uInt32&	GetControlWord() 			{ return nControlBits; }
 
 	USHORT	GetPrevParagraph() const	{ return nPrevPara; }
 	USHORT&	GetPrevParagraph() 			{ return nPrevPara; }
Index: inc/editview.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/editview.hxx,v
retrieving revision 1.15
retrieving revision 1.15.106.1
diff -u -r1.15 -r1.15.106.1
--- inc/editview.hxx	8 Sep 2005 17:33:02 -0000	1.15
+++ inc/editview.hxx	26 Oct 2005 18:06:50 -0000	1.15.106.1
@@ -199,14 +199,14 @@
 	void				RemoveAttribs( BOOL bRemoveParaAttribs = FALSE, USHORT nWhich = 0 );
 	void 				RemoveCharAttribs( USHORT nPara, USHORT nWhich = 0 );
 
-    ULONG           Read( SvStream& rInput, const String& rBaseURL, EETextFormat eFormat, BOOL bSelect = FALSE, SvKeyValueIterator* pHTTPHeaderAttrs = NULL );
-	ULONG			Write( SvStream& rOutput, EETextFormat eFormat );
+	sal_uInt32		Read( SvStream& rInput, const String& rBaseURL, EETextFormat eFormat, BOOL bSelect = FALSE, SvKeyValueIterator* pHTTPHeaderAttrs = NULL );
+	sal_uInt32		Write( SvStream& rOutput, EETextFormat eFormat );
 
 	void 			SetBackgroundColor( const Color& rColor );
 	Color			GetBackgroundColor() const;
 
-	void			SetControlWord( ULONG nWord );
-	ULONG			GetControlWord() const;
+	void			SetControlWord( sal_uInt32 nWord );
+	sal_uInt32		GetControlWord() const;
 
 	EditTextObject*	CreateTextObject();
 	void			InsertText( const EditTextObject& rTextObject );
Index: inc/lrspitem.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/lrspitem.hxx,v
retrieving revision 1.6
retrieving revision 1.6.102.1
diff -u -r1.6 -r1.6.102.1
--- inc/lrspitem.hxx	8 Sep 2005 18:02:18 -0000	1.6
+++ inc/lrspitem.hxx	26 Oct 2005 18:06:51 -0000	1.6.102.1
@@ -101,8 +101,8 @@
 	TYPEINFO();
 
 	SvxLRSpaceItem( const USHORT nId = ITEMID_LRSPACE );
-	SvxLRSpaceItem( const long nLeft, const long nRight,
-					const long nTLeft = 0, const short nOfset = 0,
+	SvxLRSpaceItem( const sal_Int32 nLeft, const sal_Int32 nRight,
+					const sal_Int32 nTLeft = 0, const short nOfset = 0,
 					const USHORT nId = ITEMID_LRSPACE );
 	inline SvxLRSpaceItem& operator=( const SvxLRSpaceItem &rCpy );
 
Index: inc/msdffimp.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/msdffimp.hxx,v
retrieving revision 1.28
retrieving revision 1.27.104.2
diff -u -r1.28 -r1.27.104.2
--- inc/msdffimp.hxx	1 Feb 2006 19:00:21 -0000	1.28
+++ inc/msdffimp.hxx	23 Feb 2006 10:43:26 -0000	1.27.104.2
@@ -515,9 +515,9 @@
 	static BOOL ReadCommonRecordHeader( DffRecordHeader& rRec, SvStream& rIn );
 	static BOOL ReadCommonRecordHeader( SvStream& rSt,
 										BYTE&     rVer,
-										USHORT&   rInst,
-										USHORT&   rFbt,
-										ULONG&    rLength );
+										sal_uInt16& rInst,
+										sal_uInt16& rFbt,
+										sal_uInt32& rLength );
 /*
 	Konstruktor
 	===========
@@ -565,7 +565,7 @@
 
 	void SetModel(SdrModel* pModel, long nApplicationScale);
 	SdrModel*  GetModel() const { return pSdrModel; }
-	void Scale(long& rVal) const;
+	void Scale(sal_Int32& rVal) const;
 	void Scale(Point& rPos) const;
 	void Scale(Size& rSiz) const;
 	void Scale(Rectangle& rRect) const;
@@ -573,7 +573,7 @@
 	void Scale(PolyPolygon& rPoly) const;
 	void Scale(XPolygon& rPoly) const;
 	void Scale(XPolyPolygon& rPoly) const;
-	void ScaleEmu(long& rVal) const;
+	void ScaleEmu(sal_Int32& rVal) const;
 	UINT32 ScalePt( UINT32 nPt ) const;
 	INT32 ScalePoint( INT32 nVal ) const;
 
Index: inc/rulritem.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/rulritem.hxx,v
retrieving revision 1.8
retrieving revision 1.8.102.1
diff -u -r1.8 -r1.8.102.1
--- inc/rulritem.hxx	8 Sep 2005 18:24:25 -0000	1.8
+++ inc/rulritem.hxx	26 Oct 2005 18:06:51 -0000	1.8.102.1
@@ -203,7 +203,7 @@
 class SVX_DLLPUBLIC SvxColumnItem : public SfxPoolItem
 {
 	SvxColumns aColumns;// Spaltenarray
-	long	nLeft,		// Linker Rand bei Tabelle
+	sal_Int32	nLeft,		// Linker Rand bei Tabelle
 		   nRight;		// Rechter Rand bei Tabelle; bei Spalten immer gleich
 						// zum umgebenden Rahmen
 	USHORT nActColumn;	// die aktuelle Spalte
@@ -271,10 +271,10 @@
 class SVX_DLLPUBLIC SvxObjectItem : public SfxPoolItem
 {
 private:
-	long   nStartX;					   /* Beginn in X-Richtung */
-	long   nEndX;					   /* Ende in X-Richtung */
-	long   nStartY;                    /* Beginn in Y-Richtung */
-	long   nEndY;                      /* Ende in Y-Richtung */
+	sal_Int32   nStartX;					   /* Beginn in X-Richtung */
+	sal_Int32   nEndX;					   /* Ende in X-Richtung */
+	sal_Int32   nStartY;                    /* Beginn in Y-Richtung */
+	sal_Int32   nEndY;                      /* Ende in Y-Richtung */
 	BOOL   bLimits;					   /* Grenzwertkontrolle durch die Applikation */
 protected:
 	virtual int 			 operator==( const SfxPoolItem& ) const;
@@ -299,10 +299,10 @@
 
 	BOOL   HasLimits() const { return bLimits; }
 
-	long   GetStartX() const { return nStartX; }
-	long   GetEndX() const { return nEndX; }
-	long   GetStartY() const { return nStartY; }
-	long   GetEndY() const { return nEndY; }
+	sal_Int32   GetStartX() const { return nStartX; }
+	sal_Int32   GetEndX() const { return nEndX; }
+	sal_Int32   GetStartY() const { return nStartY; }
+	sal_Int32   GetEndY() const { return nEndY; }
 
 	void   SetStartX(long l) { nStartX = l; }
 	void   SetEndX(long l) { nEndX = l; }
Index: inc/svdmodel.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/svdmodel.hxx,v
retrieving revision 1.50
retrieving revision 1.48.100.3
diff -u -r1.50 -r1.48.100.3
--- inc/svdmodel.hxx	20 Jan 2006 09:28:35 -0000	1.50
+++ inc/svdmodel.hxx	23 Feb 2006 10:44:25 -0000	1.48.100.3
@@ -362,10 +362,10 @@
 	// Zeichenobjekte verwenden moechte. Setzt man degegen nur vom abstrakten
 	// Basisobjekt SdrObject abgeleitete Objekte ein, so ist man frei in der
 	// Wahl des Pools.
-	SdrModel(SfxItemPool* pPool=NULL, SfxObjectShell* pPers=NULL, INT32 bLoadRefCounts = LOADREFCOUNTS);
-	SdrModel(const String& rPath, SfxItemPool* pPool=NULL, SfxObjectShell* pPers=NULL, INT32 bLoadRefCounts = LOADREFCOUNTS);
-	SdrModel(SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, INT32 bLoadRefCounts = LOADREFCOUNTS);
-	SdrModel(const String& rPath, SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, INT32 bLoadRefCounts = LOADREFCOUNTS);
+	SdrModel(SfxItemPool* pPool=NULL, SfxObjectShell* pPers=NULL, sal_Bool bLoadRefCounts = LOADREFCOUNTS);
+	SdrModel(const String& rPath, SfxItemPool* pPool=NULL, SfxObjectShell* pPers=NULL, sal_Bool bLoadRefCounts = LOADREFCOUNTS);
+	SdrModel(SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, sal_Bool bLoadRefCounts = LOADREFCOUNTS);
+	SdrModel(const String& rPath, SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, sal_Bool bLoadRefCounts = LOADREFCOUNTS);
 	virtual ~SdrModel();
 
 	// #116168#
Index: inc/tstpitem.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/tstpitem.hxx,v
retrieving revision 1.6
retrieving revision 1.6.104.1
diff -u -r1.6 -r1.6.104.1
--- inc/tstpitem.hxx	8 Sep 2005 19:20:21 -0000	1.6
+++ inc/tstpitem.hxx	26 Oct 2005 18:06:52 -0000	1.6.104.1
@@ -62,7 +62,7 @@
 class SVX_DLLPUBLIC SvxTabStop
 {
 private:
-	long            nTabPos;
+	sal_Int32            nTabPos;
 
 	SvxTabAdjust    eAdjustment;
 	sal_Unicode		cDecimal;
@@ -84,8 +84,8 @@
 				const sal_Unicode cFil = cDfltFillChar );
 #endif
 
-	long&           GetTabPos() { return nTabPos; }
-	long            GetTabPos() const { return nTabPos; }
+	sal_Int32&           GetTabPos() { return nTabPos; }
+	sal_Int32            GetTabPos() const { return nTabPos; }
 
 	SvxTabAdjust&   GetAdjustment() { return eAdjustment; }
 	SvxTabAdjust    GetAdjustment() const { return eAdjustment; }
Index: inc/xhatch.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/xhatch.hxx,v
retrieving revision 1.4
retrieving revision 1.4.106.1
diff -u -r1.4 -r1.4.106.1
--- inc/xhatch.hxx	8 Sep 2005 19:44:31 -0000	1.4
+++ inc/xhatch.hxx	26 Oct 2005 18:06:53 -0000	1.4.106.1
@@ -55,8 +55,8 @@
 protected:
 	XHatchStyle		eStyle;
 	Color			aColor;
-	long			nDistance;
-	long			nAngle;
+	sal_Int32		nDistance;
+	sal_Int32			nAngle;
 
 public:
 					XHatch() {}
@@ -72,8 +72,8 @@
 
 	XHatchStyle		GetHatchStyle() const { return eStyle; }
 	Color			GetColor() const { return aColor; }
-	long			GetDistance() const { return nDistance; }
-	long			GetAngle() const { return nAngle; }
+	sal_Int32			GetDistance() const { return nDistance; }
+	sal_Int32			GetAngle() const { return nAngle; }
 };
 
 #endif
Index: source/accessibility/AccessibleContextBase.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/accessibility/AccessibleContextBase.cxx,v
retrieving revision 1.21
retrieving revision 1.21.106.1
diff -u -r1.21 -r1.21.106.1
--- source/accessibility/AccessibleContextBase.cxx	8 Sep 2005 20:13:15 -0000	1.21
+++ source/accessibility/AccessibleContextBase.cxx	26 Oct 2005 18:06:53 -0000	1.21.106.1
@@ -261,7 +261,7 @@
     an exception for a wrong index.
 */
 uno::Reference<XAccessible> SAL_CALL
-    AccessibleContextBase::getAccessibleChild (long nIndex)
+    AccessibleContextBase::getAccessibleChild (sal_Int32 nIndex)
     throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
 {
     ThrowIfDisposed ();
Index: source/accessibility/AccessibleShape.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/accessibility/AccessibleShape.cxx,v
retrieving revision 1.47
retrieving revision 1.47.102.1
diff -u -r1.47 -r1.47.102.1
--- source/accessibility/AccessibleShape.cxx	8 Sep 2005 20:17:41 -0000	1.47
+++ source/accessibility/AccessibleShape.cxx	26 Oct 2005 18:06:53 -0000	1.47.102.1
@@ -1054,7 +1054,7 @@
     // of the same type.  If such an index where not given to the
     // constructor then use the z-order instead.  If even that does not exist
     // we throw an exception.
-    long nIndex = mnIndex;
+    sal_Int32 nIndex = mnIndex;
     if (nIndex == -1)
     {
         try
Index: source/accessibility/AccessibleStringWrap.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/accessibility/AccessibleStringWrap.cxx,v
retrieving revision 1.4
retrieving revision 1.4.106.1
diff -u -r1.4 -r1.4.106.1
--- source/accessibility/AccessibleStringWrap.cxx	8 Sep 2005 20:18:50 -0000	1.4
+++ source/accessibility/AccessibleStringWrap.cxx	26 Oct 2005 18:06:54 -0000	1.4.106.1
@@ -78,7 +78,7 @@
     }
     else
     {
-        long aXArray[2];
+        sal_Int32 aXArray[2];
         mrDev.GetCaretPositions( maText, aXArray, static_cast< USHORT >(nIndex), 1 );
         rRect.Left() = 0;
         rRect.Top() = 0;
Index: source/accessibility/DGColorNameLookUp.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/accessibility/DGColorNameLookUp.cxx,v
retrieving revision 1.3
retrieving revision 1.3.106.1
diff -u -r1.3 -r1.3.106.1
--- source/accessibility/DGColorNameLookUp.cxx	8 Sep 2005 20:21:10 -0000	1.3
+++ source/accessibility/DGColorNameLookUp.cxx	26 Oct 2005 18:06:54 -0000	1.3.106.1
@@ -86,7 +86,7 @@
 
 
 
-OUString DGColorNameLookUp::LookUpColor (long int nColor) const
+OUString DGColorNameLookUp::LookUpColor (sal_Int32 nColor) const
 {
     OUString sColorName;
     tColorValueToNameMap::const_iterator I;
@@ -146,7 +146,7 @@
             try
             {
                 uno::Any aColor (xNA->getByName (aNames[i]));
-                long nColor;
+                sal_Int32 nColor;
                 aColor >>= nColor;
                 maColorValueToNameMap[nColor] = aNames[i];
             }
Index: source/accessibility/DescriptionGenerator.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/accessibility/DescriptionGenerator.cxx,v
retrieving revision 1.7
retrieving revision 1.7.106.1
diff -u -r1.7 -r1.7.106.1
--- source/accessibility/DescriptionGenerator.cxx	8 Sep 2005 20:21:26 -0000	1.7
+++ source/accessibility/DescriptionGenerator.cxx	26 Oct 2005 18:06:55 -0000	1.7.106.1
@@ -328,7 +328,7 @@
     try
     {
         
-        long nValue;
+        sal_Int32 nValue;
         if (mxSet.is())
         {
             uno::Any aValue = mxSet->getPropertyValue (sPropertyName);
@@ -368,7 +368,7 @@
         if (mxSet.is())
         {
             uno::Any aValue = mxSet->getPropertyValue (sPropertyName);
-            long nValue;
+            sal_Int32 nValue;
             aValue >>= nValue;
             msDescription.append (nValue);
         }
Index: source/dialog/connpooloptions.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/connpooloptions.cxx,v
retrieving revision 1.5
retrieving revision 1.5.106.1
diff -u -r1.5 -r1.5.106.1
--- source/dialog/connpooloptions.cxx	8 Sep 2005 20:45:25 -0000	1.5
+++ source/dialog/connpooloptions.cxx	26 Oct 2005 18:06:55 -0000	1.5.106.1
@@ -116,7 +116,7 @@
 		virtual void CursorMoved();
 
 	protected:
-		virtual ULONG GetTotalCellWidth(long nRow, USHORT nColId);
+		virtual sal_uInt32 GetTotalCellWidth(long nRow, USHORT nColId);
 
 
 	private:
@@ -235,7 +235,7 @@
 	}
 
 	//--------------------------------------------------------------------
-	ULONG DriverListControl::GetTotalCellWidth(long nRow, USHORT nColId)
+	sal_uInt32 DriverListControl::GetTotalCellWidth(long nRow, USHORT nColId)
 	{
 		return GetDataWindow().GetTextWidth(GetCellText(nRow, nColId));
 	}
Index: source/dialog/optdict.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/optdict.cxx,v
retrieving revision 1.5
retrieving revision 1.5.106.1
diff -u -r1.5 -r1.5.106.1
--- source/dialog/optdict.cxx	8 Sep 2005 21:40:54 -0000	1.5
+++ source/dialog/optdict.cxx	26 Oct 2005 18:06:55 -0000	1.5.106.1
@@ -586,8 +586,8 @@
 
 	if (aWordsLB.GetEntryCount())
 	{
-		aWordED	  .SetText( aWordsLB.GetEntryText(0LU, 0) );
-		aReplaceED.SetText( aWordsLB.GetEntryText(0LU, 1) );
+		aWordED	  .SetText( aWordsLB.GetEntryText(0UL, 0) );
+		aReplaceED.SetText( aWordsLB.GetEntryText(0UL, 1) );
 	}
 
 	LeaveWait();
Index: source/dialog/optmemory.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/optmemory.cxx,v
retrieving revision 1.8
retrieving revision 1.8.106.1
diff -u -r1.8 -r1.8.106.1
--- source/dialog/optmemory.cxx	8 Sep 2005 21:47:15 -0000	1.8
+++ source/dialog/optmemory.cxx	26 Oct 2005 18:06:56 -0000	1.8.106.1
@@ -173,34 +173,34 @@
 #define BYTES2NF		(1.0/NF2BYTES)					// 10/2^20
 
 
-inline long OfaMemoryOptionsPage::GetNfGraphicCacheVal( void ) const
+inline sal_Size OfaMemoryOptionsPage::GetNfGraphicCacheVal( void ) const
 {
 	return aNfGraphicCache.GetValue() << 20;
 }
 
-inline void OfaMemoryOptionsPage::SetNfGraphicCacheVal( long nSizeInBytes )
+inline void OfaMemoryOptionsPage::SetNfGraphicCacheVal( sal_Size nSizeInBytes )
 {
 	aNfGraphicCache.SetValue( nSizeInBytes >> 20 );
 }
 
-long OfaMemoryOptionsPage::GetNfGraphicObjectCacheVal( void ) const
+sal_Size OfaMemoryOptionsPage::GetNfGraphicObjectCacheVal( void ) const
 {
-	return long( ::rtl::math::round( double( aNfGraphicObjectCache.GetValue() ) * NF2BYTES ) );
+	return sal_Size( ::rtl::math::round( double( aNfGraphicObjectCache.GetValue() ) * NF2BYTES ) );
 }
 
-void OfaMemoryOptionsPage::SetNfGraphicObjectCacheVal( long nSizeInBytes )
+void OfaMemoryOptionsPage::SetNfGraphicObjectCacheVal( sal_Size nSizeInBytes )
 {
-	aNfGraphicObjectCache.SetValue( long( ::rtl::math::round( double( nSizeInBytes ) * BYTES2NF ) ) );
+	aNfGraphicObjectCache.SetValue( sal_Size( ::rtl::math::round( double( nSizeInBytes ) * BYTES2NF ) ) );
 }
 
-inline void OfaMemoryOptionsPage::SetNfGraphicObjectCacheMax( long nSizeInBytes )
+inline void OfaMemoryOptionsPage::SetNfGraphicObjectCacheMax( sal_Size nSizeInBytes )
 {
-	aNfGraphicObjectCache.SetMax( long( double( nSizeInBytes ) * BYTES2NF ) );
+	aNfGraphicObjectCache.SetMax( sal_Size( double( nSizeInBytes ) * BYTES2NF ) );
 }
 
-inline void OfaMemoryOptionsPage::SetNfGraphicObjectCacheLast( long nSizeInBytes )
+inline void OfaMemoryOptionsPage::SetNfGraphicObjectCacheLast( sal_Size nSizeInBytes )
 {
-	aNfGraphicObjectCache.SetLast( long( double( nSizeInBytes ) * BYTES2NF ) );
+	aNfGraphicObjectCache.SetLast( sal_Size( double( nSizeInBytes ) * BYTES2NF ) );
 }
 
 int OfaMemoryOptionsPage::DeactivatePage( SfxItemSet* pSet )
@@ -315,7 +315,7 @@
     aUndoEdit.SaveValue();
 
     // GraphicCache
-	long	n = aCacheOptions.GetGraphicManagerTotalCacheSize();
+	sal_Size	n = aCacheOptions.GetGraphicManagerTotalCacheSize();
 	SetNfGraphicCacheVal( n );
 	SetNfGraphicObjectCacheVal( Min( GetNfGraphicCacheVal(), aCacheOptions.GetGraphicManagerObjectCacheSize() ) );
 
@@ -342,7 +342,7 @@
 
 IMPL_LINK( OfaMemoryOptionsPage, GraphicCacheConfigHdl, NumericField*, pEd )
 {
-	long	n = GetNfGraphicCacheVal();
+	sal_Size	n = GetNfGraphicCacheVal();
 	SetNfGraphicObjectCacheMax( n );
 	SetNfGraphicObjectCacheLast( n );
 
Index: source/dialog/optmemory.hxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/optmemory.hxx,v
retrieving revision 1.4
retrieving revision 1.4.106.1
diff -u -r1.4 -r1.4.106.1
--- source/dialog/optmemory.hxx	8 Sep 2005 21:47:46 -0000	1.4
+++ source/dialog/optmemory.hxx	26 Oct 2005 18:06:56 -0000	1.4.106.1
@@ -84,13 +84,13 @@
 
 	DECL_LINK( GraphicCacheConfigHdl, NumericField* );
 
-	inline long			GetNfGraphicCacheVal( void ) const;					// returns # of Bytes
-	inline void			SetNfGraphicCacheVal( long nSizeInBytes );
+	inline sal_Size			GetNfGraphicCacheVal( void ) const;					// returns # of Bytes
+	inline void			SetNfGraphicCacheVal( sal_Size nSizeInBytes );
 
-	long				GetNfGraphicObjectCacheVal( void ) const;			// returns # of Bytes
-	void				SetNfGraphicObjectCacheVal( long nSizeInBytes );
-	inline void			SetNfGraphicObjectCacheMax( long nSizeInBytes );
-	inline void			SetNfGraphicObjectCacheLast( long nSizeInBytes );
+	sal_Size				GetNfGraphicObjectCacheVal( void ) const;			// returns # of Bytes
+	void				SetNfGraphicObjectCacheVal( sal_Size nSizeInBytes );
+	inline void			SetNfGraphicObjectCacheMax( sal_Size nSizeInBytes );
+	inline void			SetNfGraphicObjectCacheLast( sal_Size nSizeInBytes );
 protected:
 	virtual int         DeactivatePage( SfxItemSet* pSet = NULL );
 
Index: source/dialog/swpossizetabpage.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/swpossizetabpage.cxx,v
retrieving revision 1.7
retrieving revision 1.7.104.1
diff -u -r1.7 -r1.7.104.1
--- source/dialog/swpossizetabpage.cxx	8 Sep 2005 22:09:55 -0000	1.7
+++ source/dialog/swpossizetabpage.cxx	26 Oct 2005 18:06:56 -0000	1.7.104.1
@@ -978,12 +978,12 @@
     }
 
     pItem = GetItem( rSet, SID_ATTR_TRANSFORM_WIDTH );
-    sal_Int32 nWidth = Max( pItem ? ( static_cast<const SfxUInt32Item*>(pItem)->GetValue()) : 0, (UINT32)1 );
+    sal_Int32 nWidth = Max( pItem ? ( static_cast<const SfxUInt32Item*>(pItem)->GetValue()) : 0, sal_uInt32( 1 ) );
 
     m_aWidthMF.SetValue(m_aWidthMF.Normalize(nWidth), FUNIT_TWIP);
 
     pItem = GetItem( rSet, SID_ATTR_TRANSFORM_HEIGHT );
-    sal_Int32 nHeight = Max( pItem ? ( static_cast<const SfxUInt32Item*>(pItem)->GetValue()) : 0, (UINT32)1 );
+    sal_Int32 nHeight = Max( pItem ? ( static_cast<const SfxUInt32Item*>(pItem)->GetValue()) : 0, sal_uInt32( 1 ) );
     m_aHeightMF.SetValue(m_aHeightMF.Normalize(nHeight), FUNIT_TWIP);
     m_fWidthHeightRatio = nHeight ? double(nWidth) / double(nHeight) : 1.0;
 
Index: source/dialog/tpline.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/tpline.cxx,v
retrieving revision 1.30
retrieving revision 1.29.100.2
diff -u -r1.30 -r1.29.100.2
--- source/dialog/tpline.cxx	28 Dec 2005 17:36:51 -0000	1.30
+++ source/dialog/tpline.cxx	16 Jan 2006 12:48:53 -0000	1.29.100.2
@@ -1014,7 +1014,7 @@
 		VirtualDevice aVDev;
 		aVDev.SetMapMode(MapMode(MAP_100TH_MM));
 
-		SdrModel* pModel = new SdrModel(NULL, NULL, LOADREFCOUNTS);
+		SdrModel* pModel = new SdrModel((SfxItemPool*)NULL, (SfxObjectShell*)NULL, (sal_Bool)LOADREFCOUNTS);
 		pModel->GetItemPool().FreezeIdRanges();
 		SdrPage* pPage = new SdrPage( *pModel, FALSE );
 		pPage->SetSize(Size(1000,1000));
Index: source/dialog/transfrm.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/transfrm.cxx,v
retrieving revision 1.19
retrieving revision 1.19.104.1
diff -u -r1.19 -r1.19.104.1
--- source/dialog/transfrm.cxx	8 Sep 2005 22:19:21 -0000	1.19
+++ source/dialog/transfrm.cxx	26 Oct 2005 18:06:57 -0000	1.19.104.1
@@ -1171,10 +1171,10 @@
 */  }
 
 	pItem = GetItem( mrOutAttrs, SID_ATTR_TRANSFORM_WIDTH );
-	mlOldWidth = Max( pItem ? ( (const SfxUInt32Item*)pItem )->GetValue() : 0, (UINT32)1 );
+	mlOldWidth = Max( pItem ? ( (const SfxUInt32Item*)pItem )->GetValue() : 0, sal_uInt32( 1 ) );
 
 	pItem = GetItem( mrOutAttrs, SID_ATTR_TRANSFORM_HEIGHT );
-	mlOldHeight = Max( pItem ? ( (const SfxUInt32Item*)pItem )->GetValue() : 0, (UINT32)1 );
+	mlOldHeight = Max( pItem ? ( (const SfxUInt32Item*)pItem )->GetValue() : 0, sal_uInt32( 1 ) );
 
 	Fraction aUIScale = mpView->GetModel()->GetUIScale();
 
@@ -1279,8 +1279,8 @@
 {
 	if( pSet )
 	{
-		INT32 lX = maMtrPosX.GetValue();
-		INT32 lY = maMtrPosY.GetValue();
+		long lX = maMtrPosX.GetValue();
+		long lY = maMtrPosY.GetValue();
 
 		// #106330#
 		// The below BugFix assumed that GetTopLeftPosition()
@@ -1575,7 +1575,7 @@
 
 //------------------------------------------------------------------------
 
-void SvxPositionSizeTabPage::GetTopLeftPosition( INT32& rX, INT32& rY,
+void SvxPositionSizeTabPage::GetTopLeftPosition( long& rX, long& rY,
 												const Rectangle& rRect )
 {
 	switch ( maCtlPos.GetActualRP() )
Index: source/dialog/transfrm.hxx
===================================================================
RCS file: /cvs/graphics/svx/source/dialog/transfrm.hxx,v
retrieving revision 1.4
retrieving revision 1.4.106.1
diff -u -r1.4 -r1.4.106.1
--- source/dialog/transfrm.hxx	8 Sep 2005 22:19:50 -0000	1.4
+++ source/dialog/transfrm.hxx	26 Oct 2005 18:06:58 -0000	1.4.106.1
@@ -159,7 +159,7 @@
 //  DECL_LINK( SetOrientHdl, ListBox * );
 
 	void SetMinMaxPosition();
-	void GetTopLeftPosition( INT32& rX, INT32& rY, const Rectangle& rRect );
+	void GetTopLeftPosition( long& rX, long& rY, const Rectangle& rRect );
 #endif
 
 #if _SOLAR__PRIVATE
Index: source/editeng/editdoc.hxx
===================================================================
RCS file: /cvs/graphics/svx/source/editeng/editdoc.hxx,v
retrieving revision 1.23
retrieving revision 1.22.52.2
diff -u -r1.23 -r1.22.52.2
--- source/editeng/editdoc.hxx	10 Jan 2006 14:01:03 -0000	1.23
+++ source/editeng/editdoc.hxx	16 Jan 2006 12:49:33 -0000	1.22.52.2
@@ -442,7 +442,7 @@
 
 class ParaPortion;
 
-SV_DECL_VARARR( CharPosArray, long, 0, CHARPOSGROW );
+SV_DECL_VARARR( CharPosArray, sal_Int32, 0, CHARPOSGROW );
 
 // ------------------------------------------------------------------------
 // class EditLine
Index: source/editeng/editdoc2.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/editeng/editdoc2.cxx,v
retrieving revision 1.13
retrieving revision 1.13.52.1
diff -u -r1.13 -r1.13.52.1
--- source/editeng/editdoc2.cxx	5 Oct 2005 13:23:48 -0000	1.13
+++ source/editeng/editdoc2.cxx	26 Oct 2005 18:06:58 -0000	1.13.52.1
@@ -72,7 +72,7 @@
 
 DBG_NAME( EE_ParaPortion );
 
-SV_IMPL_VARARR( CharPosArray, long );
+SV_IMPL_VARARR( CharPosArray, sal_Int32 );
 
 /*
 
Index: source/editeng/editeng.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/editeng/editeng.cxx,v
retrieving revision 1.97
retrieving revision 1.94.100.3
diff -u -r1.97 -r1.94.100.3
--- source/editeng/editeng.cxx	1 Feb 2006 12:57:04 -0000	1.97
+++ source/editeng/editeng.cxx	23 Feb 2006 10:50:58 -0000	1.94.100.3
@@ -2360,7 +2360,7 @@
 // =====================================================================
 // ======================   Virtuelle Methoden   =======================
 // =====================================================================
-void __EXPORT EditEngine::DrawingText( const Point&, const XubString&, USHORT nTextStart, USHORT nTextLen, const long*, const SvxFont&, sal_uInt16 nPara, sal_uInt16 nIndex, BYTE nRightToLeft )
+void __EXPORT EditEngine::DrawingText( const Point&, const XubString&, USHORT nTextStart, USHORT nTextLen, const sal_Int32*, const SvxFont&, sal_uInt16 nPara, sal_uInt16 nIndex, BYTE nRightToLeft )
 {
 	DBG_CHKTHIS( EditEngine, 0 );
 }
Index: source/editeng/impedit2.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/editeng/impedit2.cxx,v
retrieving revision 1.107
retrieving revision 1.102.18.3
diff -u -r1.107 -r1.102.18.3
--- source/editeng/impedit2.cxx	1 Feb 2006 12:57:43 -0000	1.107
+++ source/editeng/impedit2.cxx	23 Feb 2006 10:51:23 -0000	1.102.18.3
@@ -2843,14 +2843,14 @@
 	return aPaM;
 }
 
-ULONG ImpEditEngine::GetTextHeight() const
+sal_uInt32 ImpEditEngine::GetTextHeight() const
 {
 	DBG_ASSERT( GetUpdateMode(), "Sollte bei Update=FALSE nicht verwendet werden: GetTextHeight" );
 	DBG_ASSERT( IsFormatted() || IsFormatting(), "GetTextHeight: Nicht formatiert" );
 	return nCurTextHeight;
 }
 
-ULONG ImpEditEngine::CalcTextWidth( BOOL bIgnoreExtraSpace )
+sal_uInt32 ImpEditEngine::CalcTextWidth( BOOL bIgnoreExtraSpace )
 {
 	// Wenn noch nicht formatiert und nicht gerade dabei.
 	// Wird in der Formatierung bei AutoPageSize gerufen.
@@ -2913,10 +2913,10 @@
 		nMaxWidth = 0;
 
 	nMaxWidth++; // Ein breiter, da in CreateLines bei >= umgebrochen wird.
-	return (ULONG)nMaxWidth;
+	return (sal_uInt32)nMaxWidth;
 }
 
-ULONG ImpEditEngine::CalcLineWidth( ParaPortion* pPortion, EditLine* pLine, BOOL bIgnoreExtraSpace )
+sal_uInt32 ImpEditEngine::CalcLineWidth( ParaPortion* pPortion, EditLine* pLine, BOOL bIgnoreExtraSpace )
 {
 	USHORT nPara = GetEditDoc().GetPos( pPortion->GetNode() );
     
@@ -2929,7 +2929,7 @@
     SvxAdjust eJustification = GetJustification( nPara );
 
     // Berechnung der Breite ohne die Indents...
-	ULONG nWidth = 0;
+	sal_uInt32 nWidth = 0;
     USHORT nPos = pLine->GetStart();
 	for ( USHORT nTP = pLine->GetStartPortion(); nTP <= pLine->GetEndPortion(); nTP++ )
 	{
@@ -2967,10 +2967,10 @@
     return nWidth;
 }
 
-ULONG ImpEditEngine::CalcTextHeight()
+sal_uInt32 ImpEditEngine::CalcTextHeight()
 {
 	DBG_ASSERT( GetUpdateMode(), "Sollte bei Update=FALSE nicht verwendet werden: CalcTextHeight" );
-	ULONG nY = 0;
+	sal_uInt32 nY = 0;
 	for ( USHORT nPortion = 0; nPortion < GetParaPortions().Count(); nPortion++ )
 		nY += GetParaPortions()[nPortion]->GetHeight();
 	return nY;
@@ -3017,9 +3017,9 @@
 	return 0xFFFF;
 }
 
-ULONG ImpEditEngine::GetParaHeight( USHORT nParagraph )
+sal_uInt32 ImpEditEngine::GetParaHeight( USHORT nParagraph )
 {
-	ULONG nHeight = 0;
+	sal_uInt32 nHeight = 0;
 
 	ParaPortion* pPPortion = GetParaPortions().SaveGetObject( nParagraph );
 	DBG_ASSERT( pPPortion, "Absatz nicht gefunden: GetParaHeight" );
Index: source/editeng/impedit3.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/editeng/impedit3.cxx,v
retrieving revision 1.105
retrieving revision 1.102.16.3
diff -u -r1.105 -r1.102.16.3
--- source/editeng/impedit3.cxx	24 Jan 2006 14:48:18 -0000	1.105
+++ source/editeng/impedit3.cxx	23 Feb 2006 10:51:31 -0000	1.102.16.3
@@ -457,7 +457,7 @@
 			aStatus.GetStatusWord() |= !IsVertical() ? EE_STAT_TEXTHEIGHTCHANGED : EE_STAT_TEXTWIDTHCHANGED;
 		if ( nNewHeight < nCurTextHeight )
 		{
-			aInvalidRec.Bottom() = (long)Max( nNewHeight, nCurTextHeight );
+			aInvalidRec.Bottom() = Max( long(nNewHeight), long(nCurTextHeight) );
 			if ( aInvalidRec.IsEmpty() )
 			{
 				aInvalidRec.Top() = 0;
@@ -751,7 +751,7 @@
 	SvxFont aTmpFont( pNode->GetCharAttribs().GetDefFont() );
 
 	sal_Bool bCalcCharPositions = sal_True;
-	long* pBuf = new long[ pNode->Len() ];
+	sal_Int32* pBuf = new sal_Int32[ pNode->Len() ];
 
 	sal_Bool bSameLineAgain = sal_False;	// Fuer TextRanger, wenn sich die Hoehe aendert.
 	TabInfo aCurrentTab;
@@ -1063,7 +1063,7 @@
 
                 // And now check for Compression:
                 if ( pPortion->GetLen() && GetAsianCompressionMode() )
-                    bCompressedChars |= ImplCalcAsianCompression( pNode, pPortion, nTmpPos, (long*)pLine->GetCharPosArray().GetData() + (nTmpPos-pLine->GetStart()), 10000, FALSE );
+                    bCompressedChars |= ImplCalcAsianCompression( pNode, pPortion, nTmpPos, const_cast< sal_Int32* >( pLine->GetCharPosArray().GetData() + (nTmpPos-pLine->GetStart()) ), 10000, FALSE );
 
 				nTmpWidth += pPortion->GetSize().Width();
 
Index: source/editeng/impedit4.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/editeng/impedit4.cxx,v
retrieving revision 1.62
retrieving revision 1.60.18.3
diff -u -r1.62 -r1.60.18.3
--- source/editeng/impedit4.cxx	24 Jan 2006 16:50:32 -0000	1.62
+++ source/editeng/impedit4.cxx	23 Feb 2006 10:51:40 -0000	1.60.18.3
@@ -2813,7 +2813,7 @@
 
 			xub_StrLen nLen = nCurrentEnd - nCurrentStart;
 
-			Sequence <long> aOffsets;
+			Sequence <sal_Int32> aOffsets;
 			String aNewText( aTranslitarationWrapper.transliterate( *pNode, nLanguage, nCurrentStart, nLen, &aOffsets ) );
 
 			if( ( nLen != aNewText.Len() ) || !pNode->Equals( aNewText, nCurrentStart, nLen ) )
@@ -2838,7 +2838,7 @@
 
                 // Change text without loosing the attributes
                 USHORT nCharsAfterTransliteration = aOffsets.getLength();
-                const long* pOffsets = aOffsets.getConstArray();
+                const sal_Int32* pOffsets = aOffsets.getConstArray();
                 short nDiffs = 0;
                 for ( USHORT n = 0; n < nCharsAfterTransliteration; n++ )
                 {
Index: source/fmcomp/fmgridcl.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/fmcomp/fmgridcl.cxx,v
retrieving revision 1.52
retrieving revision 1.51.76.2
diff -u -r1.52 -r1.51.76.2
--- source/fmcomp/fmgridcl.cxx	25 Jan 2006 15:06:15 -0000	1.52
+++ source/fmcomp/fmgridcl.cxx	23 Feb 2006 10:52:07 -0000	1.51.76.2
@@ -2198,7 +2198,7 @@
 	}
 }
 // -----------------------------------------------------------------------------
-long FmGridControl::GetSelectedColumn() const		
+sal_Int32 FmGridControl::GetSelectedColumn() const		
 { 
 	return m_nCurrentSelectedColumn; 
 }
Index: source/form/filtnav.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/form/filtnav.cxx,v
retrieving revision 1.39
retrieving revision 1.39.104.1
diff -u -r1.39 -r1.39.104.1
--- source/form/filtnav.cxx	8 Sep 2005 22:50:01 -0000	1.39
+++ source/form/filtnav.cxx	26 Oct 2005 18:07:01 -0000	1.39.104.1
@@ -1347,7 +1347,7 @@
 	if (aText.Len() == 0)
 	{
 		// deleting the entry asynchron
-		sal_uInt32 nEvent;
+		sal_uIntPtr nEvent;
 		PostUserEvent(nEvent, LINK(this, FmFilterNavigator, OnRemove), pEntry);
 	}
 	else
Index: source/form/fmexpl.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/form/fmexpl.cxx,v
retrieving revision 1.32
retrieving revision 1.32.104.1
diff -u -r1.32 -r1.32.104.1
--- source/form/fmexpl.cxx	8 Sep 2005 22:52:54 -0000	1.32
+++ source/form/fmexpl.cxx	26 Oct 2005 18:07:01 -0000	1.32.104.1
@@ -385,7 +385,7 @@
 void FmEntryData::Clear()
 {
     FmEntryData* pEntryData;
-    while( pEntryData = GetChildList()->Remove(sal_uInt32(0)) )
+    while( pEntryData = GetChildList()->Remove(0UL) )
         delete pEntryData;
 }
 
Index: source/form/fmvwimp.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/form/fmvwimp.cxx,v
retrieving revision 1.49
retrieving revision 1.46.74.3
diff -u -r1.49 -r1.46.74.3
--- source/form/fmvwimp.cxx	31 Jan 2006 18:39:05 -0000	1.49
+++ source/form/fmvwimp.cxx	23 Feb 2006 10:52:58 -0000	1.46.74.3
@@ -1726,8 +1726,8 @@
 	aRealSize.Height()= aDefSize.Height();
 
 	// je nach Skalierung des Zieldevices muss die Groesse noch normiert werden (#53523#)
-	aRealSize.Width() = sal_Int32(Fraction(aRealSize.Width(), 1) * eTargetMode.GetScaleX());
-	aRealSize.Height() = sal_Int32(Fraction(aRealSize.Height(), 1) * eTargetMode.GetScaleY());
+	aRealSize.Width() = Fraction(aRealSize.Width(), 1) * eTargetMode.GetScaleX();
+	aRealSize.Height() = Fraction(aRealSize.Height(), 1) * eTargetMode.GetScaleY();
 	_rpLabel->SetLogicRect(
 		::Rectangle(	_pOutDev->LogicToLogic(Point(0, _nYOffsetMM), eSourceMode, eTargetMode),
 					_pOutDev->LogicToLogic(aRealSize, eSourceMode, eTargetMode)
@@ -1747,8 +1747,8 @@
 		szControlSize = aDefSize;
 
 	// normieren wie oben
-	szControlSize.Width() = sal_Int32(Fraction(szControlSize.Width(), 1) * eTargetMode.GetScaleX());
-	szControlSize.Height() = sal_Int32(Fraction(szControlSize.Height(), 1) * eTargetMode.GetScaleY());
+	szControlSize.Width() = Fraction(szControlSize.Width(), 1) * eTargetMode.GetScaleX();
+	szControlSize.Height() = Fraction(szControlSize.Height(), 1) * eTargetMode.GetScaleY();
 	_rpControl->SetLogicRect(
 		::Rectangle(	_pOutDev->LogicToLogic(Point(aRealSize.Width(), _nYOffsetMM), eSourceMode, eTargetMode),
 					_pOutDev->LogicToLogic(szControlSize, eSourceMode, eTargetMode)
Index: source/inc/DGColorNameLookUp.hxx
===================================================================
RCS file: /cvs/graphics/svx/source/inc/DGColorNameLookUp.hxx,v
retrieving revision 1.3
retrieving revision 1.3.106.1
diff -u -r1.3 -r1.3.106.1
--- source/inc/DGColorNameLookUp.hxx	8 Sep 2005 23:09:59 -0000	1.3
+++ source/inc/DGColorNameLookUp.hxx	26 Oct 2005 18:07:02 -0000	1.3.106.1
@@ -76,7 +76,7 @@
             color or, when no name exists, a string of the form "#RRGGBB"
             with two hexadecimal digits for each color component.
     */
-    ::rtl::OUString LookUpColor (long int nColor) const;
+    ::rtl::OUString LookUpColor (sal_Int32 nColor) const;
 
 private:
     /// Define hash map type to convert numerical color values to names.
Index: source/inc/GraphCtlAccessibleContext.hxx
===================================================================
RCS file: /cvs/graphics/svx/source/inc/GraphCtlAccessibleContext.hxx,v
retrieving revision 1.10
retrieving revision 1.10.106.1
diff -u -r1.10 -r1.10.106.1
--- source/inc/GraphCtlAccessibleContext.hxx	8 Sep 2005 23:10:13 -0000	1.10
+++ source/inc/GraphCtlAccessibleContext.hxx	26 Oct 2005 18:07:02 -0000	1.10.106.1
@@ -184,8 +184,8 @@
 
 	//=====  XAccessibleContext  ==============================================
 
-    virtual long SAL_CALL getAccessibleChildCount (void) throw (::com::sun::star::uno::RuntimeException);
-    virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible> SAL_CALL getAccessibleChild (long nIndex) throw (::com::sun::star::uno::RuntimeException, ::com::sun::star::lang::IndexOutOfBoundsException);
+    virtual sal_Int32 SAL_CALL getAccessibleChildCount (void) throw (::com::sun::star::uno::RuntimeException);
+    virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible> SAL_CALL getAccessibleChild (sal_Int32 nIndex) throw (::com::sun::star::uno::RuntimeException, ::com::sun::star::lang::IndexOutOfBoundsException);
 	virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible> SAL_CALL getAccessibleParent (void) throw (::com::sun::star::uno::RuntimeException);
 	virtual	sal_Int32 SAL_CALL getAccessibleIndexInParent (void) throw (::com::sun::star::uno::RuntimeException);
 	virtual sal_Int16 SAL_CALL getAccessibleRole (void) throw (::com::sun::star::uno::RuntimeException);
Index: source/inc/svxrectctaccessiblecontext.hxx
===================================================================
RCS file: /cvs/graphics/svx/source/inc/svxrectctaccessiblecontext.hxx,v
retrieving revision 1.10
retrieving revision 1.10.106.1
diff -u -r1.10 -r1.10.106.1
--- source/inc/svxrectctaccessiblecontext.hxx	8 Sep 2005 23:27:01 -0000	1.10
+++ source/inc/svxrectctaccessiblecontext.hxx	26 Oct 2005 18:07:02 -0000	1.10.106.1
@@ -199,11 +199,11 @@
 
 	//=====  XAccessibleContext  ==============================================
 
-	virtual long SAL_CALL
+	virtual sal_Int32 SAL_CALL
 		getAccessibleChildCount( void ) throw( ::com::sun::star::uno::RuntimeException );
 
 	virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible> SAL_CALL
-		getAccessibleChild( long nIndex )
+		getAccessibleChild( sal_Int32 nIndex )
 			throw( ::com::sun::star::uno::RuntimeException, ::com::sun::star::lang::IndexOutOfBoundsException );
 
 	virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible> SAL_CALL
Index: source/items/paraitem.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/items/paraitem.cxx,v
retrieving revision 1.31
retrieving revision 1.29.100.2
diff -u -r1.31 -r1.29.100.2
--- source/items/paraitem.cxx	10 Jan 2006 14:01:31 -0000	1.31
+++ source/items/paraitem.cxx	16 Jan 2006 12:56:31 -0000	1.29.100.2
@@ -119,8 +119,8 @@
 using namespace ::com::sun::star;
 
 // Konvertierung fuer UNO
-#define TWIP_TO_MM100(TWIP) 	((TWIP) >= 0 ? (((TWIP)*127L+36L)/72L) : (((TWIP)*127L-36L)/72L))
-#define MM100_TO_TWIP(MM100)	((MM100) >= 0 ? (((MM100)*72L+63L)/127L) : (((MM100)*72L-63L)/127L))
+#define TWIP_TO_MM100(TWIP) 	((TWIP) >= 0 ? (((TWIP)*127+36)/72) : (((TWIP)*127-36)/72))
+#define MM100_TO_TWIP(MM100)	((MM100) >= 0 ? (((MM100)*72+63)/127) : (((MM100)*72-63)/127))
 
 
 // STATIC DATA -----------------------------------------------------------
Index: source/msfilter/msdffimp.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/msfilter/msdffimp.cxx,v
retrieving revision 1.129
retrieving revision 1.126.18.3
diff -u -r1.129 -r1.126.18.3
--- source/msfilter/msdffimp.cxx	1 Feb 2006 19:01:26 -0000	1.129
+++ source/msfilter/msdffimp.cxx	23 Feb 2006 10:55:47 -0000	1.126.18.3
@@ -3454,7 +3454,7 @@
         aUniqueID( rUniqueID ) {}
 };
 
-void SvxMSDffManager::Scale( long& rVal ) const
+void SvxMSDffManager::Scale( sal_Int32& rVal ) const
 {
 	if ( bNeedMap )
 		rVal = BigMulDiv( rVal, nMapMul, nMapDiv );
@@ -3528,7 +3528,7 @@
 		Scale( rPoly[ nPolyNum ] );
 }
 
-void SvxMSDffManager::ScaleEmu( long& rVal ) const
+void SvxMSDffManager::ScaleEmu( sal_Int32& rVal ) const
 {
 	rVal = BigMulDiv( rVal, nEmuMul, nEmuDiv );
 }
@@ -4809,7 +4809,7 @@
 	aObjData.bChildAnchor = maShapeRecords.SeekToContent( rSt, DFF_msofbtChildAnchor, SEEK_FROM_CURRENT_AND_RESTART );
 	if ( aObjData.bChildAnchor )
 	{
-        INT32 l, o, r, u;
+        sal_Int32 l, o, r, u;
         rSt >> l >> o >> r >> u;
         Scale( l );
         Scale( o );
@@ -5426,7 +5426,7 @@
 					{
 						sal_Int16 ls, os, rs, us;
 						rSt >> os >> ls >> rs >> us; // etwas seltsame Koordinatenreihenfolge ...
-						long l = ls, o = os, r = rs, u = us;
+						sal_Int32 l = ls, o = os, r = rs, u = us;
 						Scale( l );
 						Scale( o );
 						Scale( r );
@@ -6362,9 +6362,9 @@
 	rStCtrl.Seek( nOffsDgg );
 
 	BYTE   nVer;
-	USHORT nInst;
-	USHORT nFbt;
-	ULONG  nLength;
+	sal_uInt16 nInst;
+	sal_uInt16 nFbt;
+	sal_uInt32 nLength;
 	if( !this->ReadCommonRecordHeader( rStCtrl, nVer, nInst, nFbt, nLength ) ) return;
 
 	BOOL bOk;
@@ -6407,9 +6407,9 @@
 void SvxMSDffManager::GetDrawingGroupContainerData( SvStream& rSt, ULONG nLenDgg )
 {
 	BYTE   nVer;
-	USHORT nInst;
-	USHORT nFbt;
-	ULONG  nLength;
+	sal_uInt16 nInst;
+	sal_uInt16 nFbt;
+	sal_uInt32 nLength;
 
 	ULONG nLenBStoreCont = 0, nLenFBSE = 0, nRead = 0;
 
@@ -6494,7 +6494,10 @@
 //
 void SvxMSDffManager::GetDrawingContainerData( SvStream& rSt, ULONG nLenDg )
 {
-	BYTE nVer;USHORT nInst;USHORT nFbt;ULONG nLength;
+	BYTE nVer;
+	sal_uInt16 nInst;
+	sal_uInt16 nFbt;
+	sal_uInt32 nLength;
 
 	ULONG nReadDg = 0;
 
@@ -6527,7 +6530,10 @@
 												  ULONG nLenShapeGroupCont,
 												  BOOL bPatriarch )
 {
-	BYTE nVer;USHORT nInst;USHORT nFbt;ULONG nLength;
+	BYTE nVer;
+	sal_uInt16 nInst;
+	sal_uInt16 nFbt;
+	sal_uInt32 nLength;
 	long nStartShapeGroupCont = rSt.Tell();
 	// Wir stehen in einem Shape Group Container (ggfs. mehrere pro Seite)
 	// und muessen nun
@@ -6566,7 +6572,10 @@
 
 BOOL SvxMSDffManager::GetShapeContainerData( SvStream& rSt, ULONG nLenShapeCont, ULONG nPosGroup )
 {
-	BYTE nVer;USHORT nInst;USHORT nFbt;ULONG nLength;
+	BYTE nVer;
+	sal_uInt16 nInst;
+	sal_uInt16 nFbt;
+	sal_uInt32 nLength;
 	long  nStartShapeCont = rSt.Tell();
 	// Wir stehen in einem Shape Container (ggfs. mehrere pro Sh. Group)
 	// und muessen nun
@@ -6929,9 +6938,9 @@
 	int nRes = GRFILTER_OPENERROR;  // Fehlervariable initialisieren
 
 	// nachschauen, ob es sich auch wirklich um ein BLIP handelt
-	ULONG  nLength;
-	USHORT nInst, nFbt;
 	BYTE   nVer;
+	sal_uInt16 nInst, nFbt;
+	sal_uInt32 nLength;
 	if( ReadCommonRecordHeader( rBLIPStream, nVer, nInst, nFbt, nLength) && ( 0xF018 <= nFbt ) && ( 0xF117 >= nFbt ) )
 	{
 		Size		aMtfSize100;
@@ -7102,9 +7111,9 @@
 /* auch static */
 BOOL SvxMSDffManager::ReadCommonRecordHeader( SvStream& rSt,
 											  BYTE&     rVer,
-											  USHORT&   rInst,
-											  USHORT&   rFbt,
-											  ULONG&    rLength )
+											  sal_uInt16& rInst,
+											  sal_uInt16& rFbt,
+											  sal_uInt32& rLength )
 {
 	sal_uInt16 nTmp;
 	rSt >> nTmp >> rFbt >> rLength;
Index: source/outliner/outliner.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/outliner/outliner.cxx,v
retrieving revision 1.65
retrieving revision 1.61.52.3
diff -u -r1.65 -r1.61.52.3
--- source/outliner/outliner.cxx	1 Feb 2006 12:58:29 -0000	1.65
+++ source/outliner/outliner.cxx	23 Feb 2006 10:56:31 -0000	1.61.52.3
@@ -1173,14 +1173,14 @@
 				else
 				{
 					Font aSvxFont( aBulletFont );
-					long* pBuf = new long[ pPara->GetText().Len() ];
+					sal_Int32* pBuf = new sal_Int32[ pPara->GetText().Len() ];
 					pOutDev->GetTextArray( pPara->GetText(), pBuf );
 					// aTextPos ist Bottom, jetzt die Baseline liefern:
 					FontMetric aMetric( pOutDev->GetFontMetric() );
 					aTextPos.Y() -= aMetric.GetDescent();
 
 					// #101498#
-					DrawingText( aTextPos, pPara->GetText(), 0, pPara->GetText().Len(), pBuf, aSvxFont, nPara, 0xFFFF, 0xFF);
+					DrawingText( aTextPos, pPara->GetText(), (USHORT)0, pPara->GetText().Len(), pBuf, aSvxFont, nPara, 0xFFFF, 0xFF);
 
 					delete[] pBuf;
 				}
Index: source/svdraw/svdedtv2.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/svdraw/svdedtv2.cxx,v
retrieving revision 1.20
retrieving revision 1.19.102.2
diff -u -r1.20 -r1.19.102.2
--- source/svdraw/svdedtv2.cxx	10 Jan 2006 14:49:28 -0000	1.20
+++ source/svdraw/svdedtv2.cxx	16 Jan 2006 12:59:52 -0000	1.19.102.2
@@ -875,7 +875,7 @@
 
 					// clear list
 					while(aEntryList.Count())
-						delete aEntryList.Remove((UINT32)0L);
+						delete aEntryList.Remove(0UL);
 				}
 
 				if(eVer != SvxDistributeVerticalNone)
@@ -963,7 +963,7 @@
 
 					// clear list
 					while(aEntryList.Count())
-						delete aEntryList.Remove((UINT32)0L);
+						delete aEntryList.Remove(0UL);
 				}
 
 				// UNDO-Comment and end of UNDO
Index: source/svdraw/svdfppt.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/svdraw/svdfppt.cxx,v
retrieving revision 1.136
retrieving revision 1.134.52.2
diff -u -r1.136 -r1.134.52.2
--- source/svdraw/svdfppt.cxx	9 Feb 2006 14:09:20 -0000	1.136
+++ source/svdraw/svdfppt.cxx	23 Feb 2006 10:57:16 -0000	1.134.52.2
@@ -804,7 +804,7 @@
 {
 	INT16 ls, os, rs, us;
 	rSt >> os >> ls >> rs >> us; // etwas seltsame Koordinatenreihenfolge ...
-	long l = ls, o = os, r = rs, u = us;
+	sal_Int32 l = ls, o = os, r = rs, u = us;
 	Scale( l );
 	Scale( o );
 	Scale( r );
Index: source/svdraw/svdmodel.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/svdraw/svdmodel.cxx,v
retrieving revision 1.62
retrieving revision 1.61.102.2
diff -u -r1.62 -r1.61.102.2
--- source/svdraw/svdmodel.cxx	10 Jan 2006 14:50:28 -0000	1.62
+++ source/svdraw/svdmodel.cxx	16 Jan 2006 13:00:28 -0000	1.61.102.2
@@ -303,7 +303,7 @@
 	ImpCreateTables();
 }
 
-SdrModel::SdrModel(SfxItemPool* pPool, SfxObjectShell* pPers, INT32 bLoadRefCounts):
+SdrModel::SdrModel(SfxItemPool* pPool, SfxObjectShell* pPers, sal_Bool bLoadRefCounts):
 	maPages(1024,32,32),
 	maMaPag(1024,32,32)
 {
@@ -315,7 +315,7 @@
 	ImpCtor(pPool,pPers,FALSE, (FASTBOOL)bLoadRefCounts);
 }
 
-SdrModel::SdrModel(const String& rPath, SfxItemPool* pPool, SfxObjectShell* pPers, INT32 bLoadRefCounts):
+SdrModel::SdrModel(const String& rPath, SfxItemPool* pPool, SfxObjectShell* pPers, sal_Bool bLoadRefCounts):
 	maPages(1024,32,32),
 	maMaPag(1024,32,32),
 	aTablePath(rPath)
@@ -328,7 +328,7 @@
 	ImpCtor(pPool,pPers,FALSE, (FASTBOOL)bLoadRefCounts);
 }
 
-SdrModel::SdrModel(SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, INT32 bLoadRefCounts):
+SdrModel::SdrModel(SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, sal_Bool bLoadRefCounts):
 	maPages(1024,32,32),
 	maMaPag(1024,32,32)
 {
@@ -340,7 +340,7 @@
 	ImpCtor(pPool,pPers,bUseExtColorTable, (FASTBOOL)bLoadRefCounts);
 }
 
-SdrModel::SdrModel(const String& rPath, SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, INT32 bLoadRefCounts):
+SdrModel::SdrModel(const String& rPath, SfxItemPool* pPool, SfxObjectShell* pPers, FASTBOOL bUseExtColorTable, sal_Bool bLoadRefCounts):
 	maPages(1024,32,32),
 	maMaPag(1024,32,32),
 	aTablePath(rPath)
Index: source/svdraw/svdoattr.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/svdraw/svdoattr.cxx,v
retrieving revision 1.42
retrieving revision 1.42.102.1
diff -u -r1.42 -r1.42.102.1
--- source/svdraw/svdoattr.cxx	9 Sep 2005 00:31:55 -0000	1.42
+++ source/svdraw/svdoattr.cxx	26 Oct 2005 18:07:06 -0000	1.42.102.1
@@ -544,11 +544,11 @@
 	nSttWdt /= 2;
 
 	// Lieber etwas mehr, dafuer keine Wurzel ziehen
-	long nSttAdd = Max(nSttWdt, nSttHgt);
+	sal_Int32 nSttAdd = Max(nSttWdt, nSttHgt);
 	nSttAdd *= 3;
 	nSttAdd /= 2;
 
-	long nEndWdt = ((const XLineEndWidthItem&)(rSet.Get(XATTR_LINEENDWIDTH))).GetValue();
+	sal_Int32 nEndWdt = ((const XLineEndWidthItem&)(rSet.Get(XATTR_LINEENDWIDTH))).GetValue();
 
 	if(nEndWdt < 0)
 		nEndWdt = -nLineWdt * nEndWdt / 100; // <0 = relativ
Index: source/svdraw/svdopath.cxx
===================================================================
RCS file: /cvs/graphics/svx/source/svdraw/svdopath.cxx,v
retrieving revision 1.28
retrieving revision 1.28.102.1
diff -u -r1.28 -r1.28.102.1
--- source/svdraw/svdopath.cxx	9 Sep 2005 00:35:09 -0000	1.28
+++ source/svdraw/svdopath.cxx	26 Oct 2005 18:07:06 -0000	1.28.102.1
@@ -78,6 +78,8 @@
 // #104018# replace macros above with type-safe methods
 inline sal_Int32 ImplTwipsToMM(sal_Int32 nVal) { return ((nVal * 127 + 36) / 72); }
 inline sal_Int32 ImplMMToTwips(sal_Int32 nVal) { return ((nVal * 72 + 63) / 127); }
+inline sal_Int64 ImplTwipsToMM(sal_Int64 nVal) { return ((nVal * 127 + 36) / 72); }
+inline sal_Int64 ImplMMToTwips(sal_Int64 nVal) { return ((nVal * 72 + 63) / 127); }
 inline double ImplTwipsToMM(double fVal) { return (fVal * (127.0 / 72.0)); }
 inline double ImplMMToTwips(double fVal) { return (fVal * (72.0 / 127.0)); }
 

Index: inc/editeng.hxx
===================================================================
RCS file: /cvs/graphics/svx/inc/editeng.hxx,v
retrieving revision 1.50
retrieving revision 1.47.52.3
diff -u -r1.50 -r1.47.52.3
--- inc/editeng.hxx	1 Feb 2006 12:56:17 -0000	1.50
+++ inc/editeng.hxx	23 Feb 2006 10:42:34 -0000	1.47.52.3
@@ -209,19 +209,19 @@
 
 	String			GetText( LineEnd eEnd = LINEEND_LF ) const;
 	String			GetText( const ESelection& rSelection, const LineEnd eEnd = LINEEND_LF ) const;
-	ULONG			GetTextLen() const;
-	ULONG			GetTextHeight() const;
-	ULONG			CalcTextWidth();
+	sal_uInt32		GetTextLen() const;
+	sal_uInt32		GetTextHeight() const;
+	sal_uInt32		CalcTextWidth();
 
 	String 			GetText( USHORT nParagraph ) const;
 	xub_StrLen			GetTextLen( USHORT nParagraph ) const;
-	ULONG			GetTextHeight( USHORT nParagraph ) const;
+	sal_uInt32		GetTextHeight( USHORT nParagraph ) const;
 
 	USHORT 			GetParagraphCount() const;
 
 	USHORT			GetLineCount( USHORT nParagraph ) const;
 	xub_StrLen		GetLineLen( USHORT nParagraph, USHORT nLine ) const;
-	ULONG			GetLineHeight( USHORT nParagraph, USHORT nLine = 0 );
+	sal_uInt32		GetLineHeight( USHORT nParagraph, USHORT nLine = 0 );
 	USHORT			GetFirstLineOffset( USHORT nParagraph );
 	ParagraphInfos 	GetParagraphInfos( USHORT nPara );
 	USHORT			FindParagraph( long nDocPosY );
@@ -308,9 +308,9 @@
 	void			Draw( OutputDevice* pOutDev, const Rectangle& rOutRect, const Point& rStartDocPos, BOOL bClip );
 	void			Draw( OutputDevice* pOutDev, const Point& rStartPos, short nOrientation = 0 );
 
-//  ULONG: Fehlercode des Streams.
-    ULONG           Read( SvStream& rInput, const String& rBaseURL, EETextFormat, SvKeyValueIterator* pHTTPHeaderAttrs = NULL );
-	ULONG			Write( SvStream& rOutput, EETextFormat );
+//  sal_uInt32: Fehlercode des Streams.
+	sal_uInt32		Read( SvStream& rInput, const String& rBaseURL, EETextFormat, SvKeyValueIterator* pHTTPHeaderAttrs = NULL );
+	sal_uInt32		Write( SvStream& rOutput, EETextFormat );
 
 	void			SetStatusEventHdl( const Link& rLink );
 	Link			GetStatusEventHdl() const;
@@ -325,8 +325,8 @@
 	BOOL			IsFlatMode() const;
 	void			SetFlatMode( BOOL bFlat );
 
-	void			SetControlWord( ULONG nWord );
-	ULONG			GetControlWord() const;
+	void			SetControlWord( sal_uInt32 nWord );
+	sal_uInt32		GetControlWord() const;
 
 	void			QuickSetAttribs( const SfxItemSet& rSet, const ESelection& rSel );
 	void 			QuickRemoveCharAttribs( USHORT nPara, USHORT nWhich = 0 );
@@ -454,7 +454,7 @@
 	virtual Rectangle GetBulletArea( USHORT nPara );
 
 	static SfxItemPool*	CreatePool( BOOL bLoadRefCounts = TRUE );
-	static ULONG	RegisterClipboardFormatName();
+	static sal_uInt32	RegisterClipboardFormatName();
 	static BOOL		DoesKeyChangeText( const KeyEvent& rKeyEvent );
 	static BOOL		DoesKeyMoveCursor( const KeyEvent& rKeyEvent );
 	static BOOL		IsSimpleCharInput( const KeyEvent& rKeyEvent );